@@ -51,8 +51,10 @@ pub use body::Body;
 pub use comment::Comment;
 pub use comments::Comments;
 pub use commit_message::CommitMessage;
+pub use commit_message::Error as CommitMessageError;
 pub use fragment::Fragment;
 pub use scissors::Scissors;
 pub use subject::Subject;
+pub use trailer::Error as TrailerError;
 pub use trailer::Trailer;
 pub use trailers::Trailers;
